.. _glossary:


********
Glossary
********

.. if you add new entries, keep the alphabetical sorting!

.. glossary::

   DBAPI

      :pep:`249` -- Python Database API Specification v2.0

   ipdb

      ipdb exports functions to access the IPython debugger, which
      features tab completion, syntax highlighting, better tracebacks,
      better introspection with the same interface as the pdb module.

   MySQL

      A popular database server.

      http://www.mysql.com/

   pep8

      Python style guide checker

      *pep8* is a tool to check your Python code against some of the
      style conventions in :pep:`8` -- Style Guide for Python Code.

   pyflakes

      passive checker of Python programs

      A simple program which checks Python source files for errors.

      Pyflakes analyzes programs and detects various errors. It works
      by parsing the source file, not importing it, so it is safe to
      use on modules with side effects. It's also much faster.

      https://pypi.python.org/pypi/pyflakes

   PyMySQL

      Pure-Python MySQL client library. The goal of PyMySQL is to be a drop-in
      replacement for MySQLdb and work on CPython, PyPy, IronPython and Jython.

      https://github.com/PyMySQL/PyMySQL

   sqlalchemy

      The Python SQL Toolkit and Object Relational Mapper.

      http://www.sqlalchemy.org/
